# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-07-20 04:01
from __future__ import unicode_literals

import ckeditor.fields
import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='EmailTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('layout_name', models.CharField(choices=[('email_layout', 'email_layout'), ('email_layout_1', 'email_layout_1'), ('email_layout_2', 'email_layout_2')], default='email_layout', max_length=255)),
                ('name', models.CharField(max_length=255, unique=True)),
                ('subject', models.CharField(max_length=255)),
                ('message', ckeditor.fields.RichTextField()),
            ],
            options={
                'db_table': 'email_templates',
            },
        ),
        migrations.CreateModel(
            name='Logs',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('log_name', models.CharField(max_length=255)),
                ('log_level', models.CharField(choices=[('log', 'Log'), ('info', 'Info'), ('exception', 'Exception'), ('error', 'Error')], default='log', max_length=50)),
                ('log_msg', models.TextField()),
                ('created_at', models.DateTimeField(blank=True, default=datetime.datetime.now)),
            ],
            options={
                'db_table': 'logs',
            },
        ),
        migrations.CreateModel(
            name='SysProcess',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content_id', models.IntegerField()),
                ('content_type', models.CharField(max_length=50)),
                ('priority', models.IntegerField()),
                ('status', models.IntegerField(default=0)),
                ('created_at', models.DateTimeField(blank=True, default=datetime.datetime.now)),
            ],
            options={
                'db_table': 'sys_process',
            },
        ),
    ]
